@@ -1,13 +1,26 @@
 .package <- new.env()
- 
+
 ## covr: skip=all
+#' @importFrom utils packageVersion
 .onLoad <- function(libname, pkgname) {
-  .package[["version"]] <- utils::packageVersion(pkgname)
+  .package[["version"]] <- packageVersion(pkgname)
+  .package[["futureCounter"]] <- 0L
 
-  debug <- isTRUE(as.logical(Sys.getenv("R_FUTURE_DEBUG", FALSE)))
-  if (debug) options(future.debug = TRUE)
-  debug <- getOption("future.debug", debug)
+  if (isTRUE(as.logical(Sys.getenv("R_FUTURE_PRUNE_PKG_CODE", "FALSE")))) {
+    prune_pkg_code()
+  }
 
+  update_package_option("future.debug", mode = "logical")
+  debug <- isTRUE(getOption("future.debug"))
+
+  ## Special case: Disable 'R_FUTURE_PLAN' when 'R CMD check'
+  ## runs checks on examples, because, for instance,
+  ## R_FUTURE_PLAN=multisession, will create connections that
+  ## the check code will think are left over connections.
+  if (nzchar(Sys.getenv("R_FUTURE_PLAN")) && "CheckExEnv" %in% search()) {
+    Sys.unsetenv("R_FUTURE_PLAN")
+  }
+  
   if (debug) {
     envs <- Sys.getenv()
     envs <- envs[grep("R_FUTURE_", names(envs), fixed = TRUE)]
@@ -15,46 +28,15 @@
     mdebug(paste(c("Future-specific environment variables:", envs), collapse = "\n"))
   }
 
-  ## Does multiprocess resolve to multisession? If so, then
-  ## plan(multiprocess) should initiate the workers.
-  if (is.na(attr(multiprocess, "init", exact = TRUE))) {
-    attr(multiprocess, "init") <<- !supportsMulticore()
-  }
+  ## Set future options based on environment variables
+  update_package_options(debug = debug)
   
   ## Initiate the R session UUID, which will also set/update
-  ## .GlobalEnv$.Random.seed.
+  ## .GlobalEnv[[".Random.seed"]].
   session_uuid(attributes = FALSE)
 
-  ## Unless already set, set option 'future.psock.relay.immediate'
-  ## according to environment variable 'R_FUTURE_PSOCK_RELAY_IMMEDIATE'.
-  relay <- getOption("future.psock.relay.immediate")
-  if (is.null(relay)) {
-    relay <- trim(Sys.getenv("R_FUTURE_PSOCK_RELAY_IMMEDIATE"))
-    if (debug) mdebugf("R_FUTURE_PSOCK_RELAY_IMMEDIATE=%s", sQuote(relay))
-    if (nzchar(relay)) {
-      relay <- as.logical(toupper(relay))
-      if (is.na(relay)) {
-        stop("Environment variable 'R_FUTURE_PSOCK_RELAY_IMMEDIATE' must be a logical value: ", sQuote(Sys.getenv("R_FUTURE_PSOCK_RELAY_IMMEDIATE")))
-      }
-      if (debug) mdebugf(" => options(future.psock.relay.immediate = %s)", relay)
-      options(future.psock.relay.immediate = relay)
-    }
-  }
-
-  ## Unless already set, set option 'future.plan' according to
-  ## system environment variable 'R_FUTURE_PLAN'.
+  ## Report on future plan, if set
   strategy <- getOption("future.plan")
-  if (is.null(strategy)) {
-    strategy <- trim(Sys.getenv("R_FUTURE_PLAN"))
-    if (nzchar(strategy)) {
-      if (debug) {
-        mdebugf("R_FUTURE_PLAN=%s", sQuote(strategy))
-        mdebugf(" => options(future.plan = '%s')", strategy)
-      }
-      options(future.plan = strategy)
-    }
-    strategy <- getOption("future.plan")
-  }
   if (!is.null(strategy)) {
     if (debug) {
       if (is.character(strategy)) {
@@ -66,7 +48,7 @@
   }
 
   args <- parseCmdArgs()
-  p <- args$p
+  p <- args[["p"]]
   if (!is.null(p)) {
     if (debug) mdebugf("R command-line argument: -p %s", p)
     
@@ -107,7 +89,7 @@
 }
 
 
-sourceFutureStartupScript <- function(default = c(".future.R", "~/.future.R"), debug = getOption("future.debug", FALSE)) {
+sourceFutureStartupScript <- function(default = c(".future.R", "~/.future.R"), debug = isTRUE(getOption("future.debug"))) {
   ## Get default from env var?
   pathnames <- Sys.getenv("R_FUTURE_STARTUP_SCRIPT")
   if (nchar(pathnames) == 0L) {
@@ -145,7 +127,7 @@ sourceFutureStartupScript <- function(default = c(".future.R", "~/.future.R"), d
     return(character(0L))
   }
   
-  if (debug) mdebug("Future startup scripts considered: ", paste(sQuote(pathnames), collapse = ", "))
+  if (debug) mdebug("Future startup scripts considered: ", commaq(pathnames))
   pathnames <- pathnames[file_test("-f", pathnames)]
 
   ## Nothing to do?
@@ -156,14 +138,14 @@ sourceFutureStartupScript <- function(default = c(".future.R", "~/.future.R"), d
   
   pathname <- pathnames[1]
   if (debug) {
-    mdebugf("Future startup scripts found: %s", paste(sQuote(pathnames), collapse = ", "))
+    mdebugf("Future startup scripts found: %s", commaq(pathnames))
     mdebugf("Future startup script to load: %s", sQuote(pathname))
   }
   
   tryCatch({
     source(pathname, chdir = FALSE, echo = FALSE, local = FALSE)
   }, error = function(ex) {
-    msg <- sprintf("Failed to source %s file while attaching the future package. Will ignore this error, but please investigate. The error message was: %s", sQuote(pathname), sQuote(ex$message))
+    msg <- sprintf("Failed to source %s file while attaching the future package. Will ignore this error, but please investigate. The error message was: %s", sQuote(pathname), sQuote(ex[["message"]]))
     if (debug) mdebug(msg)
     warning(msg)
   })
